@@ -164,7 +164,8 @@ int main(int argc, char *argv[])
 	_mosquitto_net_init();
 
 	mqtt3_config_init(&config);
-	if(mqtt3_config_parse_args(&config, argc, argv)) return 1;
+	rc = mqtt3_config_parse_args(&config, argc, argv);
+	if(rc) return rc;
 	int_db.config = &config;
 
 	if(config.daemon){
@@ -193,11 +194,13 @@ int main(int argc, char *argv[])
 			return 1;
 		}
 	}
-	if(drop_privileges(&config)) return 1;
+	rc = drop_privileges(&config);
+	if(rc) return rc;
 
-	if(mqtt3_db_open(&config, &int_db)){
+	rc = mqtt3_db_open(&config, &int_db);
+	if(rc){
 		_mosquitto_log_printf(NULL, MOSQ_LOG_ERR, "Error: Couldn't open database.");
-		return 1;
+		return rc;
 	}
 
 	/* Initialise logging only after initialising the database in case we're
@@ -213,7 +216,7 @@ int main(int argc, char *argv[])
 	mqtt3_db_messages_easy_queue(&int_db, NULL, "$SYS/broker/version", 2, strlen(buf), (uint8_t *)buf, 1);
 	snprintf(buf, 1024, "%s", TIMESTAMP);
 	mqtt3_db_messages_easy_queue(&int_db, NULL, "$SYS/broker/timestamp", 2, strlen(buf), (uint8_t *)buf, 1);
-	snprintf(buf, 1024, "%s", "$Revision: 1a04ca75e86b $"); // Requires hg keyword extension.
+	snprintf(buf, 1024, "%s", "$Revision: 5e732f3db18b $"); // Requires hg keyword extension.
 	mqtt3_db_messages_easy_queue(&int_db, NULL, "$SYS/broker/changeset", 2, strlen(buf), (uint8_t *)buf, 1);
 
 	listener_max = -1;
